Scru128Id

Struct Scru128Id 

pub struct Scru128Id(/* private fields */);
Time-sortable, 128-bit unique identifier used to order Frames.

Re-exported from the scru128 crate. Represents a SCRU128 ID and provides converters and comparison operators.

Examples

use scru128::Scru128Id;

let x = "036z968fu2tugy7svkfznewkk".parse::<Scru128Id>()?;
assert_eq!(x.to_string(), "036z968fu2tugy7svkfznewkk");

let y = Scru128Id::from(0x017fa1de51a80fd992f9e8cc2d5eb88eu128);
assert_eq!(y.to_u128(), 0x017fa1de51a80fd992f9e8cc2d5eb88eu128);

Implementations

Source

impl Scru128Id

pub const fn from_u128(int_value: u128) -> Scru128Id

Creates an object from a 128-bit unsigned integer.

pub const fn to_u128(self) -> u128

Returns the 128-bit unsigned integer representation.

pub const fn from_bytes(array_value: [u8; 16]) -> Scru128Id

Creates an object from a 16-byte big-endian byte array.

pub const fn to_bytes(self) -> [u8; 16]

Returns the big-endian byte array representation.

pub const fn as_bytes(&self) -> &[u8; 16]

Returns a reference to the big-endian byte array representation.

pub const fn from_fields( timestamp: u64, counter_hi: u32, counter_lo: u32, entropy: u32, ) -> Scru128Id

Creates an object from field values.

Panics

Panics if any argument is out of the value range of the field.

pub const fn timestamp(&self) -> u64

Returns the 48-bit timestamp field value.

pub const fn counter_hi(&self) -> u32

Returns the 24-bit counter_hi field value.

pub const fn counter_lo(&self) -> u32

Returns the 24-bit counter_lo field value.

pub const fn entropy(&self) -> u32

Returns the 32-bit entropy field value.

pub const fn try_from_str(str_value: &str) -> Result<Scru128Id, ParseError>

Creates an object from a 25-digit string representation.

Examples
use scru128::Scru128Id;

let x = Scru128Id::try_from_str("037d0xye6op48cmce8ey4xlcf")?;
let y = "037d0xye6op48cmce8ey4xlcf".parse::<Scru128Id>()?;
assert_eq!(x, y);
pub const fn encode(&self) -> FStr<25>

Returns the 25-digit string representation stored in a stack-allocated string-like type that can be handled like String through common traits.

Examples
use scru128::Scru128Id;

let x = "037d0xye6op48cmce8ey4xlcf".parse::<Scru128Id>()?;
let y = x.encode();
assert_eq!(y, "037d0xye6op48cmce8ey4xlcf");
assert_eq!(format!("{}", y), "037d0xye6op48cmce8ey4xlcf");