pub fn parse_config(
engine: &mut Engine,
script: &str,
) -> Result<NuScriptConfig, Error>Expand description
Parse a script into a NuScriptConfig struct.
Parses and evaluates the script, then extracts the run closure and the full
configuration value. VFS modules (registered via *.nu topics) are already
available on the engine state before this function is called.