Background processors that run Nushell handlers against the stream.
Modules
- action
- actor
- lifecycle
- Shared two-slot compaction state machine for actor / service / action lifecycles. See ADR 0005 for the topic vocabulary and the algorithm this implements.
- service