pub struct Scru128Id(/* private fields */);Expand description
Time-sortable, 128-bit unique identifier used to order Frames.
Re-exported from the scru128 crate.
Represents a SCRU128 ID and provides converters and comparison operators.
Examples
use scru128::Scru128Id;
let x = "036z968fu2tugy7svkfznewkk".parse::<Scru128Id>()?;
assert_eq!(x.to_string(), "036z968fu2tugy7svkfznewkk");
let y = Scru128Id::from(0x017fa1de51a80fd992f9e8cc2d5eb88eu128);
assert_eq!(y.to_u128(), 0x017fa1de51a80fd992f9e8cc2d5eb88eu128);Implementations
Sourceimpl Scru128Id
impl Scru128Id
Sourcepub const fn from_u128(int_value: u128) -> Scru128Id
pub const fn from_u128(int_value: u128) -> Scru128Id
Creates an object from a 128-bit unsigned integer.
Sourcepub const fn from_bytes(array_value: [u8; 16]) -> Scru128Id
pub const fn from_bytes(array_value: [u8; 16]) -> Scru128Id
Creates an object from a 16-byte big-endian byte array.
Sourcepub const fn as_bytes(&self) -> &[u8; 16]
pub const fn as_bytes(&self) -> &[u8; 16]
Returns a reference to the big-endian byte array representation.
Sourcepub const fn from_fields(
timestamp: u64,
counter_hi: u32,
counter_lo: u32,
entropy: u32,
) -> Scru128Id
pub const fn from_fields( timestamp: u64, counter_hi: u32, counter_lo: u32, entropy: u32, ) -> Scru128Id
Creates an object from field values.
Panics
Panics if any argument is out of the value range of the field.
Sourcepub const fn counter_hi(&self) -> u32
pub const fn counter_hi(&self) -> u32
Returns the 24-bit counter_hi field value.
Sourcepub const fn counter_lo(&self) -> u32
pub const fn counter_lo(&self) -> u32
Returns the 24-bit counter_lo field value.
Sourcepub const fn try_from_str(str_value: &str) -> Result<Scru128Id, ParseError>
pub const fn try_from_str(str_value: &str) -> Result<Scru128Id, ParseError>
Creates an object from a 25-digit string representation.
Examples
use scru128::Scru128Id;
let x = Scru128Id::try_from_str("037d0xye6op48cmce8ey4xlcf")?;
let y = "037d0xye6op48cmce8ey4xlcf".parse::<Scru128Id>()?;
assert_eq!(x, y);Sourcepub const fn encode(&self) -> FStr<25>
pub const fn encode(&self) -> FStr<25>
Returns the 25-digit string representation stored in a stack-allocated string-like type
that can be handled like String through common traits.
Examples
use scru128::Scru128Id;
let x = "037d0xye6op48cmce8ey4xlcf".parse::<Scru128Id>()?;
let y = x.encode();
assert_eq!(y, "037d0xye6op48cmce8ey4xlcf");
assert_eq!(format!("{}", y), "037d0xye6op48cmce8ey4xlcf");Trait Implementations
impl Copy for Scru128Id
Sourceimpl<'de> Deserialize<'de> for Scru128Id
impl<'de> Deserialize<'de> for Scru128Id
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Scru128Id, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Scru128Id, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl Display for Scru128Id
impl Display for Scru128Id
Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Returns the 25-digit canonical string representation.
Examples
use scru128::Scru128Id;
let x = "03997ft3ckz99o1i3f82zat1t".parse::<Scru128Id>()?;
assert_eq!(format!("{}", x), "03997ft3ckz99o1i3f82zat1t");
assert_eq!(format!("{:32}", x), "03997ft3ckz99o1i3f82zat1t ");
assert_eq!(format!("{:->32}", x), "-------03997ft3ckz99o1i3f82zat1t");
assert_eq!(format!("{:.^7.5}", x), ".03997.");impl Eq for Scru128Id
Sourceimpl Ord for Scru128Id
impl Ord for Scru128Id
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialOrd for Scru128Id
impl PartialOrd for Scru128Id
Sourceimpl Serialize for Scru128Id
impl Serialize for Scru128Id
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
impl StructuralPartialEq for Scru128Id